require 'simplecov'
SimpleCov.start do
  add_filter '/spec/'
end

$LOAD_PATH.unshift(File.dirname(__FILE__))
$LOAD_PATH.unshift(File.join(File.dirname(__FILE__), '..', 'lib'))
require 'client_pages'

require 'webmock/rspec'
require 'open-uri'

RSpec.configure do |config|
  config.treat_symbols_as_metadata_keys_with_true_values = true
  config.run_all_when_everything_filtered = true
  config.filter_run :focus
  config.order = 'random'   # --seed 1234

  config.expect_with :rspec do |c|
    c.syntax = :expect
  end

  config.mock_with :rspec do |c|
    c.syntax = :expect
  end

  config.before(:each) do
    ClientPages.configure do |c|
      c.remote = false
      c.caching = false
      c.content_path = 'spec/fixtures/content'
      c.remote_content_path = nil
      c.raw_markdown = false
      c.render_options = {
        hard_wrap: true,
        with_toc_data: false
      }
      c.markdown_extensions = {
        tables: true,
        autolink: true,
        lax_spacing: true,
        space_after_headers: true,
        underline: false,
        no_intra_emphasis: true
      }
    end
  end
end

# helper for markdown fixture files
def fixture(name)
  open("#{ClientPages.config.content_path}/#{name}.md").read
end
