require 'spec_helper'

module ClientPages
  describe Configuration do

    it 'has default config' do
      config = {
        content_path: 'content',
        render_options: {},
        markdown_extensions: {}
      }
      expect(subject.to_hash).to eql(config)
    end

    it 'is configurable' do
      config = {
        content_path: 'somewhere',
        render_options: { foo: 'bar' },
        markdown_extensions: { bam: true }
      }
      expect {
        subject.content_path = 'somewhere'
        subject.render_options = { foo: 'bar' }
        subject.markdown_extensions = { bam: true }
      }.to change {
        subject.to_hash
      }.to eql(config)
    end

    describe 'overwritable config' do
      before do
        subject.render_options = { opt1: true }
        subject.markdown_extensions = { ext1: true }
      end

      it 'overwrites config and keeps untouched config settings' do
        config = {
          content_path: 'here',
          render_options: { opt1: false, opt2: true },
          markdown_extensions: { ext1: true, ext2: false }
        }
        expect {
          subject.content_path = 'here'
          subject.render_options = { opt1: false, opt2: true }
          subject.markdown_extensions = { ext2: false }
        }.to change {
          subject.to_hash
        }.to eql(config)
      end
    end
  end
end
